==> webkit2gtk_2.44.2.orig.tar.xz: webkitgtk-2.44.2/Source/WebKit/Shared/Extensions/WebExtensionContentWorldType.h <==
/*
 * Copyright (C) 2023 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#if ENABLE(WK_WEB_EXTENSIONS)

#include <wtf/text/WTFString.h>

namespace WebKit {

enum class WebExtensionContentWorldType : uint8_t {
    Main,
    ContentScript,
    Native,
};

inline String toDebugString(WebExtensionContentWorldType contentWorldType)
{
    switch (contentWorldType) {
    case WebExtensionContentWorldType::Main:
        return "main"_s;
    case WebExtensionContentWorldType::ContentScript:
        return "content script"_s;
    case WebExtensionContentWorldType::Native:
        return "native"_s;
    }
}

} // namespace WebKit

namespace WTF {

template<> struct DefaultHash<WebKit::WebExtensionContentWorldType> : IntHash<WebKit::WebExtensionContentWorldType> { };
template<> struct HashTraits<WebKit::WebExtensionContentWorldType> : StrongEnumHashTraits<WebKit::WebExtensionContentWorldType> { };

} // namespace WTF

#endif // ENABLE(WK_WEB_EXTENSIONS)

==> webkit2gtk_2.50.2.orig.tar.xz: webkitgtk-2.50.2/Source/WebKit/Shared/Extensions/WebExtensionContentWorldType.h <==
/*
 * Copyright (C) 2023 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#if ENABLE(WK_WEB_EXTENSIONS)

#include <wtf/text/WTFString.h>

namespace WebKit {

enum class WebExtensionContentWorldType : uint8_t {
    Main,
    ContentScript,
    Native,
    WebPage,
#if ENABLE(INSPECTOR_EXTENSIONS)
    Inspector,
#endif
};

inline bool isEqual(WebExtensionContentWorldType a, WebExtensionContentWorldType b)
{
#if ENABLE(INSPECTOR_EXTENSIONS)
    // Inspector content world is a special alias of Main. Consider them equal.
    if ((a == WebExtensionContentWorldType::Main || a == WebExtensionContentWorldType::Inspector) && (b == WebExtensionContentWorldType::Main || b == WebExtensionContentWorldType::Inspector))
        return true;
#endif
    return a == b;
}

inline String toDebugString(WebExtensionContentWorldType contentWorldType)
{
    switch (contentWorldType) {
    case WebExtensionContentWorldType::Main:
        return "main"_s;
    case WebExtensionContentWorldType::ContentScript:
        return "content script"_s;
    case WebExtensionContentWorldType::Native:
        return "native"_s;
    case WebExtensionContentWorldType::WebPage:
        return "web page"_s;
#if ENABLE(INSPECTOR_EXTENSIONS)
    case WebExtensionContentWorldType::Inspector:
        return "inspector"_s;
#endif
    }
}

} // namespace WebKit

namespace WTF {

template<> struct DefaultHash<WebKit::WebExtensionContentWorldType> : IntHash<WebKit::WebExtensionContentWorldType> { };
template<> struct HashTraits<WebKit::WebExtensionContentWorldType> : StrongEnumHashTraits<WebKit::WebExtensionContentWorldType> { };

} // namespace WTF

#endif // ENABLE(WK_WEB_EXTENSIONS)
